pref("general.smoothScroll",               true);
pref("general.autoScroll",                 false);
pref("browser.urlbar.hideGoButton",        true);
pref("browser.shell.checkDefaultBrowser",  false);
pref("browser.EULA.override",              true);
pref("general.useragent.locale",           "chrome://global/locale/intl.properties");
pref("intl.locale.requested",              "");
/* Disable DoH by default */
pref("network.trr.mode",                   5);
/* Disable use of Mozilla Normandy service by default */
pref("app.normandy.enabled",               false);
/* Disable remote-settings from permissions manager by default but don't lock it
   so corporations can easily turn it back on if there's demand for that */
pref("permissions.manager.remote.enabled", false);
pref("spellchecker.dictionary_path", "/usr/share/myspell");
/* Force hardware accelerated rendering due to USE=hwaccel */
pref("gfx.webrender.all",                     true);
pref("layers.acceleration.force-enabled",     true);
pref("layers.gpu-process.enabled",            true);
pref("media.hardware-video-decoding.enabled", true);
pref("webgl.force-enabled",                   true);
pref("gfx.x11-egl.force-enabled", false);
pref("media.gmp-gmpopenh264.autoupdate", false);
pref("media.gmp-widevinecdm.autoupdate", false);
sticky_pref("gfx.font_rendering.graphite.enabled", true);
